package SPVM::Net::SSLeay::Error::SSL_ERROR_WANT_READ;



1;

=head1 Name

SPVM::Net::SSLeay::Error::SSL_ERROR_WANT_READ - The Error indicated by SSL_ERROR_WANT_READ in OpenSSL

=head1 Description

Net::SSLeay::Error::SSL_ERROR_WANT_READ class in L<SPVM> represents the error indicated by L<SSL_ERROR_WANT_READ|https://docs.openssl.org/master/man3/SSL_ERROR_WANT_READ> in OpenSSL.

=head1 Usage

  use Net::SSLeay::Error::SSL_ERROR_WANT_READ;

=head1 Super Class

L<Net::SSLeay::Error|SPVM::Net::SSLeay::Error>

=head1 Copyright & License

Copyright (c) 2024 Yuki Kimoto

MIT License

